Capability

Enum Capability 

#[non_exhaustive]
pub enum Capability {
Show 33 variants Reserved0 = 0, GetHwVersion = 1, WriteDcc = 2, AdaptiveClocking = 3, ReadConfig = 4, WriteConfig = 5, Trace = 6, WriteMem = 7, ReadMem = 8, SpeedInfo = 9, ExecCode = 10, GetMaxBlockSize = 11, GetHwInfo = 12, SetKsPower = 13, ResetStopTimed = 14, MeasureRtckReact = 16, SelectIf = 17, RwMemArm79 = 18, GetCounters = 19, ReadDcc = 20, GetCpuCaps = 21, ExecCpuCmd = 22, Swo = 23, WriteDccEx = 24, UpdateFirmwareEx = 25, FileIo = 26, Register = 27, Indicators = 28, TestNetSpeed = 29, RawTrace = 30, GetCapsEx = 31, HwJtagWrite = 32, Com = 33,
}
List of capabilities that may be advertised by a probe.

Not many of these are actually used, and a lot of these have unknown meaning.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Reserved0 = 0



GetHwVersion = 1



WriteDcc = 2



AdaptiveClocking = 3



ReadConfig = 4



WriteConfig = 5



Trace = 6



WriteMem = 7



ReadMem = 8



SpeedInfo = 9



ExecCode = 10



GetMaxBlockSize = 11



GetHwInfo = 12



SetKsPower = 13



ResetStopTimed = 14



MeasureRtckReact = 16



SelectIf = 17



RwMemArm79 = 18



GetCounters = 19



ReadDcc = 20



GetCpuCaps = 21



ExecCpuCmd = 22



Swo = 23



WriteDccEx = 24



UpdateFirmwareEx = 25



FileIo = 26



Register = 27



Indicators = 28



TestNetSpeed = 29



RawTrace = 30



GetCapsEx = 31



HwJtagWrite = 32



Com = 33